<?php
/**
 * NOTA SOBRE LA LICENCIA DE USO DEL SOFTWARE
 *
 * El uso de este software está sujeto a las Condiciones de uso de software que
 * puede obtener una copia en la siguiente url:
 * https://www.sistemapay.com/aviso-legal
 *
 * Sistemapay es titular de todos los derechos de propiedad intelectual e industrial
 * del software.
 *
 * Quedan expresamente prohibidas la reproducción, la distribución y la
 * comunicación pública, incluida su modalidad de puesta a disposición con fines
 * distintos a los descritos en las Condiciones de uso.
 *
 * Sistemapay se reserva la posibilidad de ejercer las acciones legales que le
 * correspondan para hacer valer sus derechos frente a cualquier infracción de
 * los derechos de propiedad intelectual y/o industrial.
 *
 * @author Sistema de Tarjetas y Medios de Pago S.A., NIF A87992681
 * @copyright 2024 Sistema de Tarjetas y Medios de Pago S.A.
 * @license   https://www.sistemapay.com/aviso-legal
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

class PlazoXIndicator extends Module
{
    public function __construct()
    {
        $this->name = 'plazoxindicator';
        $this->tab = 'front_office_features';
        $this->version = '0.0.1';
        $this->author = 'Sistemapay';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = [
            'min' => '1.7.0.0',
            'max' => '8.99.99',
        ];
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = 'plazox';
        $this->description = $this->l('Module to indicate the possibility of using plazox.');

        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');

        if (!Configuration::get('MYMODULE_NAME')) {
            $this->warning = $this->l('No name provided');
        }
    }

    public function install()
    {
        Configuration::updateValue('BANNER_LOGO', 1);
        Configuration::updateValue('BANNER_TOP', 1);
        Configuration::updateValue('BANNER_COLOR', 1);
        Configuration::updateValue('INDICADOR_FLOTANTE', 1);
        Configuration::updateValue('BANNER_PRODUCT', 1);
        Configuration::updateValue('BANNER_REDUCIDO', 0);

        return parent::install()
        && $this->registerHook('displayPaymentTop')
        && $this->registerHook('displayCheckoutSubtotalDetails')
        && $this->registerHook('displayProductAdditionalInfo')
        && $this->registerHook('displayCheckoutSummaryTop')
        && $this->registerHook('displayBanner')
        && $this->registerHook('displayFooter')
        && $this->registerHook('actionFrontControllerSetMedia');
    }

    public function uninstall()
    {
        return parent::uninstall();
    }

    public function hookDisplayPaymentTop($params)
    {
        $cart = $this->context->cart;
        $totalValue = $cart->getOrderTotal(true, Cart::BOTH);

        if ($totalValue >= 60) {
            return $this->display(__FILE__, 'method-payment.tpl');
        }
    }

    public function hookDisplayCheckoutSubtotalDetails($params)
    {
        $cart = $this->context->cart;
        $totalValue = $cart->getOrderTotal(true, Cart::BOTH);

        $this->context->smarty->assign('totalValue', $totalValue);

        if ('cart' == $this->context->controller->php_self) {
            return $this->display(__FILE__, 'cart.tpl');
        }
    }

    public function hookDisplayProductAdditionalInfo($params)
    {
        $allowBanner = Configuration::get('BANNER_PRODUCT');
        $bannerReducido = Configuration::get('BANNER_REDUCIDO');

        $this->context->smarty->assign('bannerReducido', $bannerReducido);
        if ($allowBanner) {
            return $this->display(__FILE__, 'product-card-logo.tpl');
        }
    }

    public function hookDisplayCheckoutSummaryTop($params)
    {
        $cart = $this->context->cart;
        $totalValue = $cart->getOrderTotal(true, Cart::BOTH);

        $this->context->smarty->assign('totalValue', $totalValue);
        return $this->display(__FILE__, 'cart.tpl');
    }

    public function hookDisplayBanner($params)
    {
        $allowBanner = Configuration::get('BANNER_TOP');
        $bannerColor = Configuration::get('BANNER_COLOR');
        $bannerLogo = Configuration::get('BANNER_LOGO');
        $bannerText = Configuration::get('BANNER_TEXT');
        $indicadorFlot = Configuration::get('INDICADOR_FLOTANTE');
        $indicadorColor = Configuration::get('INDICADOR_COLOR');

        $content = '';

        if ($allowBanner) {
            if ($bannerText == 0) {
                $bannerText = $this->l('Divide el pago con plazox');
            } else {
                $bannerText = $this->l('Paga poco a poco con plazox');
            }
            $this->context->smarty->assign('bannerLogo', $bannerLogo);
            $this->context->smarty->assign('bannerText', $bannerText);
            switch ($bannerColor) {
                case 0:
                    $this->context->smarty->assign([
                        'background_color' => '#1F1F1F',
                        'details_color' => '#FFFFFF',
                    ]);
                    $content .= $this->display(__FILE__, 'banner.tpl');
                    break;
                case 1:
                    $this->context->smarty->assign([
                        'background_color' => '#FFFFFF',
                        'details_color' => '#1F1F1F',
                    ]);
                    $content .= $this->display(__FILE__, 'banner.tpl');
                    break;
                default:
                    break;
            }
        }
        return $content;
    }

    public function hookDisplayFooter($params)
    {
        $allowBanner = Configuration::get('BANNER_BOTTOM');
        $bannerColor = Configuration::get('BANNER_COLOR');
        $bannerLogo = Configuration::get('BANNER_LOGO');
        $bannerText = Configuration::get('BANNER_TEXT');

        $content = '';

        if ($allowBanner) {
            if ($bannerText == 0) {
                $bannerText = $this->l('Divide el pago con plazox');
            } else {
                $bannerText = $this->l('Paga poco a poco con plazox');
            }
            $this->context->smarty->assign('bannerLogo', $bannerLogo);
            $this->context->smarty->assign('bannerText', $bannerText);
            switch ($bannerColor) {
                case 0:
                    $this->context->smarty->assign([
                        'background_color' => '#1F1F1F',
                        'details_color' => '#FFFFFF',
                    ]);
                    $content .= $this->display(__FILE__, 'banner.tpl');
                    break;
                case 1:
                    $this->context->smarty->assign([
                        'background_color' => '#FFFFFF',
                        'details_color' => '#1F1F1F',
                    ]);
                    $content .= $this->display(__FILE__, 'banner.tpl');
                    break;
                default:
                    break;
            }
        }
        return $content;
    }

    public function hookActionFrontControllerSetMedia()
    {
        $this->context->controller->registerStylesheet(
            'plazox-stylelocal',
            'modules/' . $this->name . '/views/css/plazox.css',
            [
                'media' => 'all',
                'priority' => 1000,
            ],
        );

        $isoCode = Context::getContext()->language->iso_code;
        if (!($isoCode == 'es' || $isoCode == 'en' || $isoCode == 'ca' || $isoCode == 'gl' || $isoCode == 'eu')) {
            $isoCode = 'es';
        }

        $indicadorFlot = Configuration::get('INDICADOR_FLOTANTE') == 1;
        $indicadorColor = Configuration::get('INDICADOR_COLOR');

        if ($indicadorFlot) {
            switch ($indicadorColor) {
                case 0:
                    $this->context->controller->registerJavascript(
                        'module-' . $this->name . '-js',
                        'modules/' . $this->name . '/views/js/' . $isoCode . '/floating-button.js',
                        [
                            'position' => 'bottom',
                            'priority' => 10,
                        ],
                    );
                    break;
                case 1:
                    $this->context->controller->registerJavascript(
                        'module-' . $this->name . '-js',
                        'modules/' . $this->name . '/views/js/' . $isoCode . '/floating-button-negative.js',
                        [
                            'position' => 'bottom',
                            'priority' => 10,
                        ],
                    );
                    break;
                case 2:
                    $this->context->controller->registerJavascript(
                        'module-' . $this->name . '-js',
                        'modules/' . $this->name . '/views/js/' . $isoCode . '/floating-button-positive.js',
                        [
                            'position' => 'bottom',
                            'priority' => 10,
                        ],
                    );
                    break;
                default:
                    break;
            }
        }
    }

    public function getContent()
    {
        $output = '';

        if (Tools::isSubmit('submit' . $this->name)) {
            Configuration::updateValue('BANNER_TOP', Tools::getValue('BANNER_TOP'));
            Configuration::updateValue('BANNER_BOTTOM', Tools::getValue('BANNER_BOTTOM'));
            Configuration::updateValue('BANNER_COLOR', Tools::getValue('BANNER_COLOR'));
            Configuration::updateValue('BANNER_TEXT', Tools::getValue('BANNER_TEXT'));
            Configuration::updateValue('BANNER_LOGO', Tools::getValue('BANNER_LOGO'));
            Configuration::updateValue('INDICADOR_FLOTANTE', Tools::getValue('INDICADOR_FLOTANTE'));
            Configuration::updateValue('INDICADOR_COLOR', Tools::getValue('INDICADOR_COLOR'));
            Configuration::updateValue('BANNER_PRODUCT', Tools::getValue('BANNER_PRODUCT'));
            Configuration::updateValue('BANNER_REDUCIDO', Tools::getValue('BANNER_REDUCIDO'));

            $output = $this->displayConfirmation($this->l('Configuración guardada'));
        }

        return $output . $this->displayForm();
    }

    public function displayForm()
    {
        $form_banner = [
            'form' => [
                'legend' => [
                    'title' => $this->l('Información en la Tienda'),
                ],
                'input' => [
                    [
                        'type' => 'switch',
                        'label' => $this->l('Banner al inicio de la página'),
                        'name' => 'BANNER_TOP',
                        'required' => false,
                        'values' => [
                            [
                                'id' => 'active_on',
                                'value' => 1,
                            ],
                            [
                                'id' => 'active_off',
                                'value' => 0,
                            ],
                        ],
                        'is_bool' => true,
                    ],
                    [
                        'type' => 'switch',
                        'label' => $this->l('Banner al final de la página'),
                        'name' => 'BANNER_BOTTOM',
                        'required' => false,
                        'values' => [
                            [
                                'id' => 'active_on',
                                'value' => 1,
                            ],
                            [
                                'id' => 'active_off',
                                'value' => 0,
                            ],
                        ],
                        'is_bool' => true,
                    ],
                    [
                        'type' => 'select',
                        'name' => 'BANNER_COLOR',
                        'label' => $this->l('Color del banner'),
                        'options' => [
                            'query' => [
                                [
                                    'id' => 0,
                                    'name' => $this->l('Negro'),
                                ],
                                [
                                    'id' => 1,
                                    'name' => $this->l('Blanco'),
                                ],
                            ],
                            'id' => 'id',
                            'name' => 'name',
                        ],
                    ],
                    [
                        'type' => 'select',
                        'name' => 'BANNER_TEXT',
                        'label' => $this->l('Texto del banner'),
                        'options' => [
                            'query' => [
                                [
                                    'id' => 0,
                                    'name' => $this->l('Divide el pago con plazox'),
                                ],
                                [
                                    'id' => 1,
                                    'name' => $this->l('Paga poco a poco con plazox'),
                                ],
                            ],
                            'id' => 'id',
                            'name' => 'name',
                        ],
                    ],
                    [
                        'type' => 'switch',
                        'label' => $this->l('Logo en el banner'),
                        'name' => 'BANNER_LOGO',
                        'required' => false,
                        'values' => [
                            [
                                'id' => 'active_on',
                                'value' => 1,
                            ],
                            [
                                'id' => 'active_off',
                                'value' => 0,
                            ],
                        ],
                        'is_bool' => true,
                    ],
                    [
                        'type' => 'switch',
                        'label' => $this->l('Indicador flotante'),
                        'name' => 'INDICADOR_FLOTANTE',
                        'required' => false,
                        'values' => [
                            [
                                'id' => 'active_on',
                                'value' => 1,
                            ],
                            [
                                'id' => 'active_off',
                                'value' => 0,
                            ],
                        ],
                        'is_bool' => true,
                    ],
                    [
                        'type' => 'select',
                        'name' => 'INDICADOR_COLOR',
                        'label' => $this->l('Color del indicador flotante'),
                        'options' => [
                            'query' => [
                                [
                                    'id' => 0,
                                    'name' => $this->l('Default'),
                                ],
                                [
                                    'id' => 1,
                                    'name' => $this->l('Negativo'),
                                ],
                                [
                                    'id' => 2,
                                    'name' => $this->l('Positivo'),
                                ],
                            ],
                            'id' => 'id',
                            'name' => 'name',
                        ],
                    ],
                ],
            ],
        ];

        $form_product = [
            'form' => [
                'legend' => [
                    'title' => $this->l('Información en el Producto'),
                ],
                'input' => [
                    [
                        'type' => 'switch',
                        'label' => $this->l('Banner en los detalles de producto'),
                        'name' => 'BANNER_PRODUCT',
                        'required' => false,
                        'values' => [
                            [
                                'id' => 'active_on',
                                'value' => 1,
                            ],
                            [
                                'id' => 'active_off',
                                'value' => 0,
                            ],
                        ],
                        'is_bool' => true,
                    ],
                    [
                        'type' => 'select',
                        'label' => $this->l('Tamaño del Banner'),
                        'name' => 'BANNER_REDUCIDO',
                        'required' => false,
                        'options' => [
                            'query' => [
                                [
                                    'id' => 0,
                                    'name' => $this->l('Normal'),
                                ],
                                [
                                    'id' => 1,
                                    'name' => $this->l('Reducido'),
                                ],
                            ],
                            'id' => 'id',
                            'name' => 'name',
                        ],
                    ],
                ],
                'buttons' => [
                    'array' => [
                        'title' => $this->l('Versión del módulo: ') . $this->version,
                        'class' => 'btn',
                        'disabled' => 'true',
                    ],
                ],
                'submit' => [
                    'title' => $this->l('Guardar configuración'),
                    'class' => 'btn btn-default pull-right',
                ],
            ],
        ];

        $helper = new HelperForm();

        $helper->table = $this->table;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex . '&' . http_build_query(['configure' => $this->name]);
        $helper->submit_action = 'submit' . $this->name;

        $helper->default_form_language = (int) Configuration::get('PS_LANG_DEFAULT');

        $helper->fields_value['BANNER_TOP'] = Tools::getValue('BANNER_TOP', Configuration::get('BANNER_TOP'));
        $helper->fields_value['BANNER_BOTTOM'] = Tools::getValue('BANNER_BOTTOM', Configuration::get('BANNER_BOTTOM'));
        $helper->fields_value['BANNER_COLOR'] = Tools::getValue('BANNER_COLOR', Configuration::get('BANNER_COLOR'));
        $helper->fields_value['BANNER_TEXT'] = Tools::getValue('BANNER_TEXT', Configuration::get('BANNER_TEXT'));
        $helper->fields_value['BANNER_LOGO'] = Tools::getValue('BANNER_LOGO', Configuration::get('BANNER_LOGO'));
        $helper->fields_value['INDICADOR_FLOTANTE'] = Tools::getValue('INDICADOR_FLOTANTE', Configuration::get('INDICADOR_FLOTANTE'));
        $helper->fields_value['INDICADOR_COLOR'] = Tools::getValue('INDICADOR_COLOR', Configuration::get('INDICADOR_COLOR'));
        $helper->fields_value['BANNER_PRODUCT'] = Tools::getValue('BANNER_PRODUCT', Configuration::get('BANNER_PRODUCT'));
        $helper->fields_value['BANNER_REDUCIDO'] = Tools::getValue('BANNER_REDUCIDO', Configuration::get('BANNER_REDUCIDO'));

        return $helper->generateForm([$form_banner, $form_product]);
    }
}
